@@ -4,12 +4,12 @@
 
 test_that("knit_tutorials() works on legal tutorials", {
   expect_null(
-    knit_tutorials("test-data/tutorial_examples/good-tutorial.Rmd")
+    knit_tutorials("fixtures/tutorial_examples/good-tutorial.Rmd")
   )
   expect_null(
     knit_tutorials(
-      c("test-data/tutorial_examples/good-tutorial.Rmd",
-        "test-data/tutorial_examples/no-info-tutorial.Rmd"))
+      c("fixtures/tutorial_examples/good-tutorial.Rmd",
+        "fixtures/tutorial_examples/no-info-tutorial.Rmd"))
   )
 })
 
@@ -26,12 +26,12 @@ test_that("knit_tutorials() works on Getting Started tutorial", {
 
 test_that("knit_tutorials() fails on illegal tutorials", {
   expect_error(
-    knit_tutorials("test-data/tutorial_examples/no-exist.Rmd")
+    knit_tutorials("fixtures/tutorial_examples/no-exist.Rmd")
     )
   expect_error(
     knit_tutorials(
-      c("test-data/tutorial_examples/good-tutorial.Rmd",
-        "test-data/tutorial_examples/no-exist.Rmd")
+      c("fixtures/tutorial_examples/good-tutorial.Rmd",
+        "fixtures/tutorial_examples/no-exist.Rmd")
       )
     )
 })
